Class: Google::Apis::DatalineageV1::DatalineageService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DatalineageV1::DatalineageService
- Defined in:
- lib/google/apis/datalineage_v1/service.rb
Overview
Data Lineage API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://datalineage.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_project_location_search_link_processes(parent, google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse
Retrieve information about LineageProcesses associated with specific links.
-
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_process(parent, google_cloud_datacatalog_lineage_v1_process_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Creates a new process.
-
#create_project_location_process_run(parent, google_cloud_datacatalog_lineage_v1_run_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Creates a new run.
-
#create_project_location_process_run_lineage_event(parent, google_cloud_datacatalog_lineage_v1_lineage_event_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Creates a new lineage event.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#delete_project_location_process(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the process with the specified name.
-
#delete_project_location_process_run(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the run with the specified name.
-
#delete_project_location_process_run_lineage_event(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes the lineage event with the specified name.
-
#get_folder_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
-
#get_organization_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
-
#get_project_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_process(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Gets the details of the specified process.
-
#get_project_location_process_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Gets the details of the specified run.
-
#get_project_location_process_run_lineage_event(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Gets details of a specified lineage event.
-
#initialize ⇒ DatalineageService
constructor
A new instance of DatalineageService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_process_run_lineage_events(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse
Lists lineage events in the given project and location.
-
#list_project_location_process_runs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse
Lists runs in the given project and location.
-
#list_project_location_processes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse
List processes in the given project and location.
-
#patch_folder_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
-
#patch_organization_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
-
#patch_project_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
-
#patch_project_location_process(name, google_cloud_datacatalog_lineage_v1_process_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Updates a process.
-
#patch_project_location_process_run(name, google_cloud_datacatalog_lineage_v1_run_object = nil, allow_missing: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Updates a run.
-
#process_project_location_open_lineage_run_event(parent, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse
Creates new lineage events together with their parents: process and run.
-
#search_project_location_lineage_streaming(parent, google_cloud_datacatalog_lineage_v1_search_lineage_streaming_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingResponse
Retrieves a streaming response of lineage links connected to the requested assets by performing a breadth-first search in the given direction.
-
#search_project_location_links(parent, google_cloud_datacatalog_lineage_v1_search_links_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse
Retrieve a list of links connected to a specific asset.
Constructor Details
#initialize ⇒ DatalineageService
Returns a new instance of DatalineageService.
47 48 49 50 51 52 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-datalineage_v1', client_version: Google::Apis::DatalineageV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#batch_project_location_search_link_processes(parent, google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse
Retrieve information about LineageProcesses associated with specific links.
LineageProcesses are transformation pipelines that result in data flowing from
source to target assets. Links between assets represent this operation.
If you have specific link names, you can use this method to verify which
LineageProcesses contribute to creating those links. See the SearchLinks
method for more information on how to retrieve link name. You can retrieve the
LineageProcess information in every project where you have the datalineage.
events.get permission. The project provided in the URL is used for Billing
and Quota.
221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 221 def batch_project_location_search_link_processes(parent, google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:batchSearchLinkProcesses', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest::Representation command.request_object = google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 458 def cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::DatalineageV1::GoogleLongrunningCancelOperationRequest::Representation command.request_object = google_longrunning_cancel_operation_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::DatalineageV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_process(parent, google_cloud_datacatalog_lineage_v1_process_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Creates a new process.
608 609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 608 def create_project_location_process(parent, google_cloud_datacatalog_lineage_v1_process_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/processes', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.request_object = google_cloud_datacatalog_lineage_v1_process_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_process_run(parent, google_cloud_datacatalog_lineage_v1_run_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Creates a new run.
801 802 803 804 805 806 807 808 809 810 811 812 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 801 def create_project_location_process_run(parent, google_cloud_datacatalog_lineage_v1_run_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/runs', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.request_object = google_cloud_datacatalog_lineage_v1_run_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_process_run_lineage_event(parent, google_cloud_datacatalog_lineage_v1_lineage_event_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Creates a new lineage event.
987 988 989 990 991 992 993 994 995 996 997 998 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 987 def create_project_location_process_run_lineage_event(parent, google_cloud_datacatalog_lineage_v1_lineage_event_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/lineageEvents', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent::Representation command.request_object = google_cloud_datacatalog_lineage_v1_lineage_event_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
493 494 495 496 497 498 499 500 501 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 493 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::DatalineageV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_process(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the process with the specified name.
644 645 646 647 648 649 650 651 652 653 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 644 def delete_project_location_process(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_process_run(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the run with the specified name.
837 838 839 840 841 842 843 844 845 846 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 837 def delete_project_location_process_run(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_process_run_lineage_event(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes the lineage event with the specified name.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 1023 def delete_project_location_process_run_lineage_event(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::DatalineageV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 77 def get_folder_location_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
146 147 148 149 150 151 152 153 154 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 146 def get_organization_location_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
384 385 386 387 388 389 390 391 392 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 384 def get_project_location_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
524 525 526 527 528 529 530 531 532 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 524 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_process(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Gets the details of the specified process.
675 676 677 678 679 680 681 682 683 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 675 def get_project_location_process(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_process_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Gets the details of the specified run.
868 869 870 871 872 873 874 875 876 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 868 def get_project_location_process_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_process_run_lineage_event(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Gets details of a specified lineage event.
1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 1054 def get_project_location_process_run_lineage_event(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
569 570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 569 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_process_run_lineage_events(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse
Lists lineage events in the given project and location. The list order is not defined.
1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 1095 def list_project_location_process_run_lineage_events(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/lineageEvents', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_process_runs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse
Lists runs in the given project and location. List order is descending by
start_time.
907 908 909 910 911 912 913 914 915 916 917 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 907 def list_project_location_process_runs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/runs', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_processes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse
List processes in the given project and location. List order is descending by insertion time.
716 717 718 719 720 721 722 723 724 725 726 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 716 def list_project_location_processes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/processes', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_folder_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 111 def patch_folder_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.request_object = google_cloud_datacatalog_lineage_configmanagement_v1_config_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 180 def patch_organization_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.request_object = google_cloud_datacatalog_lineage_configmanagement_v1_config_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 418 def patch_project_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.request_object = google_cloud_datacatalog_lineage_configmanagement_v1_config_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_process(name, google_cloud_datacatalog_lineage_v1_process_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Updates a process.
761 762 763 764 765 766 767 768 769 770 771 772 773 774 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 761 def patch_project_location_process(name, google_cloud_datacatalog_lineage_v1_process_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.request_object = google_cloud_datacatalog_lineage_v1_process_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_process_run(name, google_cloud_datacatalog_lineage_v1_run_object = nil, allow_missing: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Updates a run.
948 949 950 951 952 953 954 955 956 957 958 959 960 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 948 def patch_project_location_process_run(name, google_cloud_datacatalog_lineage_v1_run_object = nil, allow_missing: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.request_object = google_cloud_datacatalog_lineage_v1_run_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#process_project_location_open_lineage_run_event(parent, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse
Creates new lineage events together with their parents: process and run. Updates the process and run if they already exist. Mapped from Open Lineage specification: https://github.com/OpenLineage/OpenLineage/blob/main/spec/ OpenLineage.json.
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 261 def process_project_location_open_lineage_run_event(parent, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:processOpenLineageRunEvent', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_lineage_streaming(parent, google_cloud_datacatalog_lineage_v1_search_lineage_streaming_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingResponse
Retrieves a streaming response of lineage links connected to the requested
assets by performing a breadth-first search in the given direction. Links
represent the data flow between source (upstream) and target (
downstream) assets in transformation pipelines. Links are stored in the same
project as the Lineage Events that create them. This method retrieves links
from all valid locations provided in the request. This method supports Column-
Level Lineage (CLL) along with wildcard support to retrieve all CLL for an
Entity FQN. Following permissions are required to retrieve links: *
datalineage.events.get permission for the project where the link is stored
for entity-level lineage. * datalineage.events.getFields permission for the
project where the link is stored for column-level lineage. This method also
returns processes that created the links if explicitly requested by setting
max_process_per_link is non-zero and
full process details are requested via links.processes.process in the
FieldMask. Permission required to retrieve processes: *
datalineage.processes.get permission for the project where the process is
stored.
311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 311 def search_project_location_lineage_streaming(parent, google_cloud_datacatalog_lineage_v1_search_lineage_streaming_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:searchLineageStreaming', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequest::Representation command.request_object = google_cloud_datacatalog_lineage_v1_search_lineage_streaming_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_links(parent, google_cloud_datacatalog_lineage_v1_search_links_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse
Retrieve a list of links connected to a specific asset. Links represent the
data flow between source (upstream) and target (downstream) assets in
transformation pipelines. Links are stored in the same project as the Lineage
Events that create them. You can retrieve links in every project where you
have the datalineage.events.get permission. The project provided in the URL
is used for Billing and Quota.
349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 349 def search_project_location_links(parent, google_cloud_datacatalog_lineage_v1_search_links_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:searchLinks', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksRequest::Representation command.request_object = google_cloud_datacatalog_lineage_v1_search_links_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |