Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Configuration for Data Lineage. Defines different configuration options for Lineage customers to control behaviour of lineage systems.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageConfigmanagementV1Config

Returns a new instance of GoogleCloudDatacatalogLineageConfigmanagementV1Config.



55
56
57
# File 'lib/google/apis/datalineage_v1/classes.rb', line 55

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of a config from overwriting each other. It is required that systems make use of the etag in the read-modify-write cycle to perform config updates in order to avoid race conditions: An etag is returned in the response to GetConfig, and systems are expected to put that etag in the request to UpdateConfig to ensure that their change will be applied to the same version of the config. If an etag is not provided in the call to UpdateConfig, then the existing config, if any, will be overwritten. Corresponds to the JSON property etag

Returns:

  • (String)


40
41
42
# File 'lib/google/apis/datalineage_v1/classes.rb', line 40

def etag
  @etag
end

#ingestionGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestion

Defines how Lineage should be ingested for a given resource. Corresponds to the JSON property ingestion



45
46
47
# File 'lib/google/apis/datalineage_v1/classes.rb', line 45

def ingestion
  @ingestion
end

#nameString

Identifier. The resource name of the config. Format: organizations/ organization_id/locations/global/config folders/folder_id/locations/ global/config projects/project_id/locations/global/config projects/ project_number/locations/global/config Corresponds to the JSON property name

Returns:

  • (String)


53
54
55
# File 'lib/google/apis/datalineage_v1/classes.rb', line 53

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60
61
62
63
64
# File 'lib/google/apis/datalineage_v1/classes.rb', line 60

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @ingestion = args[:ingestion] if args.key?(:ingestion)
  @name = args[:name] if args.key?(:name)
end