Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Ingestion rule for Data Lineage ingestion.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRule

Returns a new instance of GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRule.



102
103
104
# File 'lib/google/apis/datalineage_v1/classes.rb', line 102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#integration_selectorGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleIntegrationSelector

Integration selector of the rule. The rule is only applied to the Integration selected by the selector. Corresponds to the JSON property integrationSelector



94
95
96
# File 'lib/google/apis/datalineage_v1/classes.rb', line 94

def integration_selector
  @integration_selector
end

#lineage_enablementGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleLineageEnablement

Lineage enablement configuration. Defines configurations for the ingestion of lineage for the resource and its children. Corresponds to the JSON property lineageEnablement



100
101
102
# File 'lib/google/apis/datalineage_v1/classes.rb', line 100

def lineage_enablement
  @lineage_enablement
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



107
108
109
110
# File 'lib/google/apis/datalineage_v1/classes.rb', line 107

def update!(**args)
  @integration_selector = args[:integration_selector] if args.key?(:integration_selector)
  @lineage_enablement = args[:lineage_enablement] if args.key?(:lineage_enablement)
end