Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleIntegrationSelector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Integration selector of the rule. The rule is only applied to the Integration selected by the selector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleIntegrationSelector

Returns a new instance of GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleIntegrationSelector.



124
125
126
# File 'lib/google/apis/datalineage_v1/classes.rb', line 124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#integrationString

Required. Integration to which the rule applies. This field can be used to specify the integration against which the ingestion rule should be applied. Corresponds to the JSON property integration

Returns:

  • (String)


122
123
124
# File 'lib/google/apis/datalineage_v1/classes.rb', line 122

def integration
  @integration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



129
130
131
# File 'lib/google/apis/datalineage_v1/classes.rb', line 129

def update!(**args)
  @integration = args[:integration] if args.key?(:integration)
end