Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Request message for BatchSearchLinkProcesses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest

Returns a new instance of GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest.



182
183
184
# File 'lib/google/apis/datalineage_v1/classes.rb', line 182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Required. An array of links to check for their associated LineageProcesses. The maximum number of items in this array is 100. If the request contains more than 100 links, it returns the INVALID_ARGUMENT error. Format: projects/ project/locations/location/links/link`. Corresponds to the JSON propertylinks`

Returns:

  • (Array<String>)


166
167
168
# File 'lib/google/apis/datalineage_v1/classes.rb', line 166

def links
  @links
end

#page_sizeFixnum

The maximum number of processes to return in a single page of the response. A page may contain fewer results than this value. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


172
173
174
# File 'lib/google/apis/datalineage_v1/classes.rb', line 172

def page_size
  @page_size
end

#page_tokenString

The page token received from a previous BatchSearchLinkProcesses call. Use it to get the next page. When requesting subsequent pages of a response, remember that all parameters must match the values you provided in the original request. Corresponds to the JSON property pageToken

Returns:

  • (String)


180
181
182
# File 'lib/google/apis/datalineage_v1/classes.rb', line 180

def page_token
  @page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



187
188
189
190
191
# File 'lib/google/apis/datalineage_v1/classes.rb', line 187

def update!(**args)
  @links = args[:links] if args.key?(:links)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
end