Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EventLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

A lineage between source and target entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1EventLink

Returns a new instance of GoogleCloudDatacatalogLineageV1EventLink.



289
290
291
# File 'lib/google/apis/datalineage_v1/classes.rb', line 289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependency_infoGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1DependencyInfo

Dependency info describes how one entity depends on another. Corresponds to the JSON property dependencyInfo



277
278
279
# File 'lib/google/apis/datalineage_v1/classes.rb', line 277

def dependency_info
  @dependency_info
end

#sourceGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property source



282
283
284
# File 'lib/google/apis/datalineage_v1/classes.rb', line 282

def source
  @source
end

#targetGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property target



287
288
289
# File 'lib/google/apis/datalineage_v1/classes.rb', line 287

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



294
295
296
297
298
# File 'lib/google/apis/datalineage_v1/classes.rb', line 294

def update!(**args)
  @dependency_info = args[:dependency_info] if args.key?(:dependency_info)
  @source = args[:source] if args.key?(:source)
  @target = args[:target] if args.key?(:target)
end