Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Lineage link between two entities.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1LineageLink

Returns a new instance of GoogleCloudDatacatalogLineageV1LineageLink.



381
382
383
# File 'lib/google/apis/datalineage_v1/classes.rb', line 381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependency_infoArray<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageLinkDependencyInfo>

Describes how the target entity is dependent on the source entity. Corresponds to the JSON property dependencyInfo



354
355
356
# File 'lib/google/apis/datalineage_v1/classes.rb', line 354

def dependency_info
  @dependency_info
end

#depthFixnum

Depth of the current link in the graph starting from 1. Corresponds to the JSON property depth

Returns:

  • (Fixnum)


359
360
361
# File 'lib/google/apis/datalineage_v1/classes.rb', line 359

def depth
  @depth
end

#locationString

The location where the LineageEvent that created the link is stored. Corresponds to the JSON property location

Returns:

  • (String)


364
365
366
# File 'lib/google/apis/datalineage_v1/classes.rb', line 364

def location
  @location
end

#processesArray<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageLinkLineageProcess>

Processes metadata associated with the link. Corresponds to the JSON property processes



369
370
371
# File 'lib/google/apis/datalineage_v1/classes.rb', line 369

def processes
  @processes
end

#sourceGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property source



374
375
376
# File 'lib/google/apis/datalineage_v1/classes.rb', line 374

def source
  @source
end

#targetGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property target



379
380
381
# File 'lib/google/apis/datalineage_v1/classes.rb', line 379

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



386
387
388
389
390
391
392
393
# File 'lib/google/apis/datalineage_v1/classes.rb', line 386

def update!(**args)
  @dependency_info = args[:dependency_info] if args.key?(:dependency_info)
  @depth = args[:depth] if args.key?(:depth)
  @location = args[:location] if args.key?(:location)
  @processes = args[:processes] if args.key?(:processes)
  @source = args[:source] if args.key?(:source)
  @target = args[:target] if args.key?(:target)
end