Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Link

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Links represent the data flow between source (upstream) and target ( downstream) assets in transformation pipelines. Links are created when LineageEvents record data transformation between related assets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1Link

Returns a new instance of GoogleCloudDatacatalogLineageV1Link.



471
472
473
# File 'lib/google/apis/datalineage_v1/classes.rb', line 471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dependency_infoArray<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LinkDependencyInfo>

Optional. The dependency info of the link (applies only to column level links). Corresponds to the JSON property dependencyInfo



443
444
445
# File 'lib/google/apis/datalineage_v1/classes.rb', line 443

def dependency_info
  @dependency_info
end

#end_timeString

The end of the last event establishing this link. Corresponds to the JSON property endTime

Returns:

  • (String)


448
449
450
# File 'lib/google/apis/datalineage_v1/classes.rb', line 448

def end_time
  @end_time
end

#nameString

Output only. Immutable. The name of the link. Format: projects/project/ locations/location/links/link`. Corresponds to the JSON propertyname`

Returns:

  • (String)


454
455
456
# File 'lib/google/apis/datalineage_v1/classes.rb', line 454

def name
  @name
end

#sourceGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property source



459
460
461
# File 'lib/google/apis/datalineage_v1/classes.rb', line 459

def source
  @source
end

#start_timeString

The start of the first event establishing this link. Corresponds to the JSON property startTime

Returns:

  • (String)


464
465
466
# File 'lib/google/apis/datalineage_v1/classes.rb', line 464

def start_time
  @start_time
end

#targetGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property target



469
470
471
# File 'lib/google/apis/datalineage_v1/classes.rb', line 469

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



476
477
478
479
480
481
482
483
# File 'lib/google/apis/datalineage_v1/classes.rb', line 476

def update!(**args)
  @dependency_info = args[:dependency_info] if args.key?(:dependency_info)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @start_time = args[:start_time] if args.key?(:start_time)
  @target = args[:target] if args.key?(:target)
end