Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Metadata describing the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1OperationMetadata

Returns a new instance of GoogleCloudDatacatalogLineageV1OperationMetadata.



639
640
641
# File 'lib/google/apis/datalineage_v1/classes.rb', line 639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp of the operation submission to the server. Corresponds to the JSON property createTime

Returns:

  • (String)


610
611
612
# File 'lib/google/apis/datalineage_v1/classes.rb', line 610

def create_time
  @create_time
end

#end_timeString

Output only. The timestamp of the operation termination, regardless of its success. This field is unset if the operation is still ongoing. Corresponds to the JSON property endTime

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/datalineage_v1/classes.rb', line 616

def end_time
  @end_time
end

#operation_typeString

Output only. The type of the operation being performed. Corresponds to the JSON property operationType

Returns:

  • (String)


621
622
623
# File 'lib/google/apis/datalineage_v1/classes.rb', line 621

def operation_type
  @operation_type
end

#resourceString

Output only. The relative name of the resource being operated on. Corresponds to the JSON property resource

Returns:

  • (String)


627
628
629
# File 'lib/google/apis/datalineage_v1/classes.rb', line 627

def resource
  @resource
end

#resource_uuidString

Output only. The UUID of the resource being operated on. Corresponds to the JSON property resourceUuid

Returns:

  • (String)


632
633
634
# File 'lib/google/apis/datalineage_v1/classes.rb', line 632

def resource_uuid
  @resource_uuid
end

#stateString

Output only. The current operation state. Corresponds to the JSON property state

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/datalineage_v1/classes.rb', line 637

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



644
645
646
647
648
649
650
651
# File 'lib/google/apis/datalineage_v1/classes.rb', line 644

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @resource = args[:resource] if args.key?(:resource)
  @resource_uuid = args[:resource_uuid] if args.key?(:resource_uuid)
  @state = args[:state] if args.key?(:state)
end