Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Origin

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Origin of a process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1Origin

Returns a new instance of GoogleCloudDatacatalogLineageV1Origin.



677
678
679
# File 'lib/google/apis/datalineage_v1/classes.rb', line 677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

If the source_type isn't CUSTOM, the value of this field should be a Google Cloud resource name of the system, which reports lineage. The project and location parts of the resource name must match the project and location of the lineage resource being created. Examples: - source_type: COMPOSER, name: " projects/foo/locations/us/environments/bar" - source_type: BIGQUERY, name: "projects/foo/locations/eu" - source_type: CUSTOM, name: " myCustomIntegration" Corresponds to the JSON property name

Returns:

  • (String)


667
668
669
# File 'lib/google/apis/datalineage_v1/classes.rb', line 667

def name
  @name
end

#source_typeString

Type of the source. Use of a source_type other than CUSTOM for process creation or updating is highly discouraged. It might be restricted in the future without notice. There will be increase in cost if you use any of the source types other than CUSTOM. Corresponds to the JSON property sourceType

Returns:

  • (String)


675
676
677
# File 'lib/google/apis/datalineage_v1/classes.rb', line 675

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



682
683
684
685
# File 'lib/google/apis/datalineage_v1/classes.rb', line 682

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @source_type = args[:source_type] if args.key?(:source_type)
end