Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinks

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Links associated with a specific process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1ProcessLinks

Returns a new instance of GoogleCloudDatacatalogLineageV1ProcessLinks.



782
783
784
# File 'lib/google/apis/datalineage_v1/classes.rb', line 782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

An array containing link details objects of the links provided in the original request. A single process can result in creating multiple links. If any of the links you provide in the request are created by the same process, they all are included in this array. Corresponds to the JSON property links



774
775
776
# File 'lib/google/apis/datalineage_v1/classes.rb', line 774

def links
  @links
end

#processString

The process name in the format of projects/project/locations/location/ processes/process`. Corresponds to the JSON propertyprocess`

Returns:

  • (String)


780
781
782
# File 'lib/google/apis/datalineage_v1/classes.rb', line 780

def process
  @process
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



787
788
789
790
# File 'lib/google/apis/datalineage_v1/classes.rb', line 787

def update!(**args)
  @links = args[:links] if args.key?(:links)
  @process = args[:process] if args.key?(:process)
end