Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

A lineage run represents an execution of a process that creates lineage events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1Run

Returns a new instance of GoogleCloudDatacatalogLineageV1Run.



700
701
702
# File 'lib/google/apis/datalineage_v1/classes.rb', line 700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Object>

Optional. The attributes of the run. Should only be used for the purpose of non-semantic management (classifying, describing or labeling the run). Up to 100 attributes are allowed. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,Object>)


668
669
670
# File 'lib/google/apis/datalineage_v1/classes.rb', line 668

def attributes
  @attributes
end

#display_nameString

Optional. A human-readable name you can set to display in a user interface. Must be not longer than 1024 characters and only contain UTF-8 letters or numbers, spaces or characters like _-:&. Corresponds to the JSON property displayName

Returns:

  • (String)


675
676
677
# File 'lib/google/apis/datalineage_v1/classes.rb', line 675

def display_name
  @display_name
end

#end_timeString

Optional. The timestamp of the end of the run. Corresponds to the JSON property endTime

Returns:

  • (String)


680
681
682
# File 'lib/google/apis/datalineage_v1/classes.rb', line 680

def end_time
  @end_time
end

#nameString

Immutable. The resource name of the run. Format: projects/project/locations/ location/processes/process/runs/run`. Can be specified or auto-assigned. runmust be not longer than 200 characters and only contain characters in a set:a-zA-Z0-9_-:. Corresponds to the JSON propertyname`

Returns:

  • (String)


688
689
690
# File 'lib/google/apis/datalineage_v1/classes.rb', line 688

def name
  @name
end

#start_timeString

Required. The timestamp of the start of the run. Corresponds to the JSON property startTime

Returns:

  • (String)


693
694
695
# File 'lib/google/apis/datalineage_v1/classes.rb', line 693

def start_time
  @start_time
end

#stateString

Required. The state of the run. Corresponds to the JSON property state

Returns:

  • (String)


698
699
700
# File 'lib/google/apis/datalineage_v1/classes.rb', line 698

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



705
706
707
708
709
710
711
712
# File 'lib/google/apis/datalineage_v1/classes.rb', line 705

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end