Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksRequest
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Request message for SearchLinks.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#source ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
-
#sources ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1MultipleEntityReference
Multiple entity reference for SearchLinksRequest.
-
#target ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
-
#targets ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1MultipleEntityReference
Multiple entity reference for SearchLinksRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLinksRequest
constructor
A new instance of GoogleCloudDatacatalogLineageV1SearchLinksRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLinksRequest
Returns a new instance of GoogleCloudDatacatalogLineageV1SearchLinksRequest.
1089 1090 1091 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1089 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
Optional. The maximum number of links to return in a single page of the
response. A page may contain fewer links than this value. If unspecified, at
most 10 links are returned. Maximum value is 100; values greater than 100 are
reduced to 100.
Corresponds to the JSON property pageSize
1059 1060 1061 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1059 def page_size @page_size end |
#page_token ⇒ String
Optional. The page token received from a previous SearchLinksRequest call.
Use it to get the next page. When requesting subsequent pages of a response,
remember that all parameters must match the values you provided in the
original request.
Corresponds to the JSON property pageToken
1067 1068 1069 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1067 def page_token @page_token end |
#source ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
Corresponds to the JSON property source
1072 1073 1074 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1072 def source @source end |
#sources ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1MultipleEntityReference
Multiple entity reference for SearchLinksRequest.
Corresponds to the JSON property sources
1077 1078 1079 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1077 def sources @sources end |
#target ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
Corresponds to the JSON property target
1082 1083 1084 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1082 def target @target end |
#targets ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1MultipleEntityReference
Multiple entity reference for SearchLinksRequest.
Corresponds to the JSON property targets
1087 1088 1089 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1087 def targets @targets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1094 1095 1096 1097 1098 1099 1100 1101 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1094 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @source = args[:source] if args.key?(:source) @sources = args[:sources] if args.key?(:sources) @target = args[:target] if args.key?(:target) @targets = args[:targets] if args.key?(:targets) end |