Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Response message for SearchLinks.
Instance Attribute Summary collapse
-
#links ⇒ Array<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Link>
The list of links for a given asset.
-
#next_page_token ⇒ String
The token to specify as
page_tokenin the subsequent call to get the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLinksResponse
constructor
A new instance of GoogleCloudDatacatalogLineageV1SearchLinksResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLinksResponse
Returns a new instance of GoogleCloudDatacatalogLineageV1SearchLinksResponse.
1119 1120 1121 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#links ⇒ Array<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Link>
The list of links for a given asset. Can be empty if the asset has no
relations of requested type (source or target).
Corresponds to the JSON property links
1111 1112 1113 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1111 def links @links end |
#next_page_token ⇒ String
The token to specify as page_token in the subsequent call to get the next
page. Omitted if there are no more pages in the response.
Corresponds to the JSON property nextPageToken
1117 1118 1119 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1117 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1124 1125 1126 1127 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1124 def update!(**args) @links = args[:links] if args.key?(:links) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |