Class: Google::Apis::DatalineageV1::DatalineageService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DatalineageV1::DatalineageService
- Defined in:
- lib/google/apis/datalineage_v1/service.rb
Overview
Data Lineage API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://datalineage.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#batch_project_location_search_link_processes(parent, google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse
Retrieve information about LineageProcesses associated with specific links.
-
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_process(parent, google_cloud_datacatalog_lineage_v1_process_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Creates a new process.
-
#create_project_location_process_run(parent, google_cloud_datacatalog_lineage_v1_run_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Creates a new run.
-
#create_project_location_process_run_lineage_event(parent, google_cloud_datacatalog_lineage_v1_lineage_event_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Creates a new lineage event.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes a long-running operation.
-
#delete_project_location_process(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the process with the specified name.
-
#delete_project_location_process_run(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the run with the specified name.
-
#delete_project_location_process_run_lineage_event(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes the lineage event with the specified name.
-
#get_folder_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
-
#get_organization_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
-
#get_project_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation.
-
#get_project_location_process(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Gets the details of the specified process.
-
#get_project_location_process_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Gets the details of the specified run.
-
#get_project_location_process_run_lineage_event(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Gets details of a specified lineage event.
-
#initialize ⇒ DatalineageService
constructor
A new instance of DatalineageService.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_process_run_lineage_events(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse
Lists lineage events in the given project and location.
-
#list_project_location_process_runs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse
Lists runs in the given project and location.
-
#list_project_location_processes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse
List processes in the given project and location.
-
#patch_folder_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
-
#patch_organization_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
-
#patch_project_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
-
#patch_project_location_process(name, google_cloud_datacatalog_lineage_v1_process_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Updates a process.
-
#patch_project_location_process_run(name, google_cloud_datacatalog_lineage_v1_run_object = nil, allow_missing: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Updates a run.
-
#process_project_location_open_lineage_run_event(parent, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse
Creates new lineage events together with their parents: process and run.
-
#search_project_location_links(parent, google_cloud_datacatalog_lineage_v1_search_links_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse
Retrieve a list of links connected to a specific asset.
Constructor Details
#initialize ⇒ DatalineageService
Returns a new instance of DatalineageService.
47 48 49 50 51 52 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-datalineage_v1', client_version: Google::Apis::DatalineageV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#batch_project_location_search_link_processes(parent, google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse
Retrieve information about LineageProcesses associated with specific links.
LineageProcesses are transformation pipelines that result in data flowing from
source to target assets. Links between assets represent this operation.
If you have specific link names, you can use this method to verify which
LineageProcesses contribute to creating those links. See the SearchLinks
method for more information on how to retrieve link name. You can retrieve the
LineageProcess information in every project where you have the datalineage.
events.get permission. The project provided in the URL is used for Billing
and Quota.
221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 221 def batch_project_location_search_link_processes(parent, google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:batchSearchLinkProcesses', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest::Representation command.request_object = google_cloud_datacatalog_lineage_v1_batch_search_link_processes_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 407 def cancel_project_location_operation(name, google_longrunning_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:cancel', ) command.request_representation = Google::Apis::DatalineageV1::GoogleLongrunningCancelOperationRequest::Representation command.request_object = google_longrunning_cancel_operation_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::DatalineageV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_process(parent, google_cloud_datacatalog_lineage_v1_process_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Creates a new process.
557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 557 def create_project_location_process(parent, google_cloud_datacatalog_lineage_v1_process_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/processes', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.request_object = google_cloud_datacatalog_lineage_v1_process_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_process_run(parent, google_cloud_datacatalog_lineage_v1_run_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Creates a new run.
750 751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 750 def create_project_location_process_run(parent, google_cloud_datacatalog_lineage_v1_run_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/runs', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.request_object = google_cloud_datacatalog_lineage_v1_run_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_process_run_lineage_event(parent, google_cloud_datacatalog_lineage_v1_lineage_event_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Creates a new lineage event.
936 937 938 939 940 941 942 943 944 945 946 947 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 936 def create_project_location_process_run_lineage_event(parent, google_cloud_datacatalog_lineage_v1_lineage_event_object = nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/lineageEvents', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent::Representation command.request_object = google_cloud_datacatalog_lineage_v1_lineage_event_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
442 443 444 445 446 447 448 449 450 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 442 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::DatalineageV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_process(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the process with the specified name.
593 594 595 596 597 598 599 600 601 602 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 593 def delete_project_location_process(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_process_run(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Deletes the run with the specified name.
786 787 788 789 790 791 792 793 794 795 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 786 def delete_project_location_process_run(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_process_run_lineage_event(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleProtobufEmpty
Deletes the lineage event with the specified name.
972 973 974 975 976 977 978 979 980 981 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 972 def delete_project_location_process_run_lineage_event(name, allow_missing: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleProtobufEmpty::Representation command.response_class = Google::Apis::DatalineageV1::GoogleProtobufEmpty command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_folder_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 77 def get_folder_location_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_organization_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
146 147 148 149 150 151 152 153 154 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 146 def get_organization_location_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Get the Config for a given resource.
333 334 335 336 337 338 339 340 341 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 333 def get_project_location_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
473 474 475 476 477 478 479 480 481 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 473 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningOperation::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_process(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Gets the details of the specified process.
624 625 626 627 628 629 630 631 632 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 624 def get_project_location_process(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_process_run(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Gets the details of the specified run.
817 818 819 820 821 822 823 824 825 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 817 def get_project_location_process_run(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_process_run_lineage_event(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
Gets details of a specified lineage event.
1003 1004 1005 1006 1007 1008 1009 1010 1011 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 1003 def get_project_location_process_run_lineage_event(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
518 519 520 521 522 523 524 525 526 527 528 529 530 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 518 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/operations', ) command.response_representation = Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleLongrunningListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_process_run_lineage_events(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse
Lists lineage events in the given project and location. The list order is not defined.
1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 1044 def list_project_location_process_run_lineage_events(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/lineageEvents', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListLineageEventsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_process_runs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse
Lists runs in the given project and location. List order is descending by
start_time.
856 857 858 859 860 861 862 863 864 865 866 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 856 def list_project_location_process_runs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/runs', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListRunsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_processes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse
List processes in the given project and location. List order is descending by insertion time.
665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 665 def list_project_location_processes(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/processes', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ListProcessesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_folder_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 111 def patch_folder_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.request_object = google_cloud_datacatalog_lineage_configmanagement_v1_config_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_organization_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 180 def patch_organization_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.request_object = google_cloud_datacatalog_lineage_configmanagement_v1_config_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config
Update the Config for a given resource.
367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 367 def patch_project_location_config(name, google_cloud_datacatalog_lineage_configmanagement_v1_config_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.request_object = google_cloud_datacatalog_lineage_configmanagement_v1_config_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageConfigmanagementV1Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_process(name, google_cloud_datacatalog_lineage_v1_process_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process
Updates a process.
710 711 712 713 714 715 716 717 718 719 720 721 722 723 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 710 def patch_project_location_process(name, google_cloud_datacatalog_lineage_v1_process_object = nil, allow_missing: nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.request_object = google_cloud_datacatalog_lineage_v1_process_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Process command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_process_run(name, google_cloud_datacatalog_lineage_v1_run_object = nil, allow_missing: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run
Updates a run.
897 898 899 900 901 902 903 904 905 906 907 908 909 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 897 def patch_project_location_process_run(name, google_cloud_datacatalog_lineage_v1_run_object = nil, allow_missing: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.request_object = google_cloud_datacatalog_lineage_v1_run_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Run command.params['name'] = name unless name.nil? command.query['allowMissing'] = allow_missing unless allow_missing.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#process_project_location_open_lineage_run_event(parent, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse
Creates new lineage events together with their parents: process and run. Updates the process and run if they already exist. Mapped from Open Lineage specification: https://github.com/OpenLineage/OpenLineage/blob/main/spec/ OpenLineage.json.
261 262 263 264 265 266 267 268 269 270 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 261 def process_project_location_open_lineage_run_event(parent, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:processOpenLineageRunEvent', ) command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse command.params['parent'] = parent unless parent.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#search_project_location_links(parent, google_cloud_datacatalog_lineage_v1_search_links_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse
Retrieve a list of links connected to a specific asset. Links represent the
data flow between source (upstream) and target (downstream) assets in
transformation pipelines. Links are stored in the same project as the Lineage
Events that create them. You can retrieve links in every project where you
have the datalineage.events.get permission. The project provided in the URL
is used for Billing and Quota.
298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/google/apis/datalineage_v1/service.rb', line 298 def search_project_location_links(parent, google_cloud_datacatalog_lineage_v1_search_links_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:searchLinks', ) command.request_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksRequest::Representation command.request_object = google_cloud_datacatalog_lineage_v1_search_links_request_object command.response_representation = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse::Representation command.response_class = Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |