Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
The soft reference to everything you can attach a lineage event to.
Instance Attribute Summary collapse
-
#field ⇒ Array<String>
Optional.
-
#fully_qualified_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1EntityReference
constructor
A new instance of GoogleCloudDatacatalogLineageV1EntityReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1EntityReference
Returns a new instance of GoogleCloudDatacatalogLineageV1EntityReference.
259 260 261 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Array<String>
Optional. Field path within the entity. Each nesting level should be a
separate value in the repeated field. The order matters. Must be empty for
asset level lineage For example to address "salary.net" subfield where "salary"
is a column and "net" is a proto field two values in the field should be
reported, the first is "salary" and the second is "net". Each field length is
limited to 500 characters. Maximum supported nesting level is 20.
Corresponds to the JSON property field
251 252 253 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 251 def field @field end |
#fully_qualified_name ⇒ String
Required. Fully Qualified Name (FQN) of the entity.
Corresponds to the JSON property fullyQualifiedName
257 258 259 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 257 def fully_qualified_name @fully_qualified_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
264 265 266 267 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 264 def update!(**args) @field = args[:field] if args.key?(:field) @fully_qualified_name = args[:fully_qualified_name] if args.key?(:fully_qualified_name) end |