Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1LineageEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
A lineage event represents an operation on assets. Within the operation, the data flows from the source to the target defined in the links field.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#links ⇒ Array<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EventLink>
Optional.
-
#name ⇒ String
Immutable.
-
#start_time ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1LineageEvent
constructor
A new instance of GoogleCloudDatacatalogLineageV1LineageEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1LineageEvent
Returns a new instance of GoogleCloudDatacatalogLineageV1LineageEvent.
298 299 300 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. The end of the transformation which resulted in this lineage event.
For streaming scenarios, it should be the end of the period from which the
lineage is being reported.
Corresponds to the JSON property endTime
275 276 277 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 275 def end_time @end_time end |
#links ⇒ Array<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EventLink>
Optional. List of source-target pairs. Can't contain more than 100 tuples.
Corresponds to the JSON property links
280 281 282 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 280 def links @links end |
#name ⇒ String
Immutable. The resource name of the lineage event. Format: projects/project/
locations/location/processes/process/runs/run/lineageEvents/
lineage_event`. Can be specified or auto-assigned.lineage_eventmust be
not longer than 200 characters and only contain characters in a set:a-zA-Z0-
9_-:.
Corresponds to the JSON propertyname`
289 290 291 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 289 def name @name end |
#start_time ⇒ String
Required. The beginning of the transformation which resulted in this lineage
event. For streaming scenarios, it should be the beginning of the period from
which the lineage is being reported.
Corresponds to the JSON property startTime
296 297 298 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 296 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
303 304 305 306 307 308 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 303 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @links = args[:links] if args.key?(:links) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |