Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Link
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1Link
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Links represent the data flow between source (upstream) and target ( downstream) assets in transformation pipelines. Links are created when LineageEvents record data transformation between related assets.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The end of the last event establishing this link.
-
#name ⇒ String
Output only.
-
#source ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
-
#start_time ⇒ String
The start of the first event establishing this link.
-
#target ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1Link
constructor
A new instance of GoogleCloudDatacatalogLineageV1Link.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1Link
Returns a new instance of GoogleCloudDatacatalogLineageV1Link.
343 344 345 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The end of the last event establishing this link.
Corresponds to the JSON property endTime
320 321 322 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 320 def end_time @end_time end |
#name ⇒ String
Output only. Immutable. The name of the link. Format: projects/project/
locations/location/links/link`.
Corresponds to the JSON propertyname`
326 327 328 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 326 def name @name end |
#source ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
Corresponds to the JSON property source
331 332 333 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 331 def source @source end |
#start_time ⇒ String
The start of the first event establishing this link.
Corresponds to the JSON property startTime
336 337 338 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 336 def start_time @start_time end |
#target ⇒ Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference
The soft reference to everything you can attach a lineage event to.
Corresponds to the JSON property target
341 342 343 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 341 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
348 349 350 351 352 353 354 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 348 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @target = args[:target] if args.key?(:target) end |