Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Metadata describing the operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#operation_type ⇒ String
Output only.
-
#resource ⇒ String
Output only.
-
#resource_uuid ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1OperationMetadata
constructor
A new instance of GoogleCloudDatacatalogLineageV1OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1OperationMetadata
Returns a new instance of GoogleCloudDatacatalogLineageV1OperationMetadata.
639 640 641 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of the operation submission to the server.
Corresponds to the JSON property createTime
610 611 612 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 610 def create_time @create_time end |
#end_time ⇒ String
Output only. The timestamp of the operation termination, regardless of its
success. This field is unset if the operation is still ongoing.
Corresponds to the JSON property endTime
616 617 618 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 616 def end_time @end_time end |
#operation_type ⇒ String
Output only. The type of the operation being performed.
Corresponds to the JSON property operationType
621 622 623 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 621 def operation_type @operation_type end |
#resource ⇒ String
Output only. The relative name of the resource being operated on.
Corresponds to the JSON property resource
627 628 629 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 627 def resource @resource end |
#resource_uuid ⇒ String
Output only. The UUID of the resource being operated on.
Corresponds to the JSON property resourceUuid
632 633 634 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 632 def resource_uuid @resource_uuid end |
#state ⇒ String
Output only. The current operation state.
Corresponds to the JSON property state
637 638 639 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 637 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
644 645 646 647 648 649 650 651 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 644 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @operation_type = args[:operation_type] if args.key?(:operation_type) @resource = args[:resource] if args.key?(:resource) @resource_uuid = args[:resource_uuid] if args.key?(:resource_uuid) @state = args[:state] if args.key?(:state) end |