Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Metadata describing the operation.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#operation_type ⇒ String
Output only.
-
#resource ⇒ String
Output only.
-
#resource_uuid ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1OperationMetadata
constructor
A new instance of GoogleCloudDatacatalogLineageV1OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1OperationMetadata
Returns a new instance of GoogleCloudDatacatalogLineageV1OperationMetadata.
471 472 473 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of the operation submission to the server.
Corresponds to the JSON property createTime
442 443 444 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 442 def create_time @create_time end |
#end_time ⇒ String
Output only. The timestamp of the operation termination, regardless of its
success. This field is unset if the operation is still ongoing.
Corresponds to the JSON property endTime
448 449 450 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 448 def end_time @end_time end |
#operation_type ⇒ String
Output only. The type of the operation being performed.
Corresponds to the JSON property operationType
453 454 455 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 453 def operation_type @operation_type end |
#resource ⇒ String
Output only. The relative name of the resource being operated on.
Corresponds to the JSON property resource
459 460 461 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 459 def resource @resource end |
#resource_uuid ⇒ String
Output only. The UUID of the resource being operated on.
Corresponds to the JSON property resourceUuid
464 465 466 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 464 def resource_uuid @resource_uuid end |
#state ⇒ String
Output only. The current operation state.
Corresponds to the JSON property state
469 470 471 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 469 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
476 477 478 479 480 481 482 483 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 476 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @operation_type = args[:operation_type] if args.key?(:operation_type) @resource = args[:resource] if args.key?(:resource) @resource_uuid = args[:resource_uuid] if args.key?(:resource_uuid) @state = args[:state] if args.key?(:state) end |