Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Link details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1ProcessLinkInfo

Returns a new instance of GoogleCloudDatacatalogLineageV1ProcessLinkInfo.



584
585
586
# File 'lib/google/apis/datalineage_v1/classes.rb', line 584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

The end of the last event establishing this link-process tuple. Corresponds to the JSON property endTime

Returns:

  • (String)


571
572
573
# File 'lib/google/apis/datalineage_v1/classes.rb', line 571

def end_time
  @end_time
end

The name of the link in the format of projects/project/locations/location/ links/link`. Corresponds to the JSON propertylink`

Returns:

  • (String)


577
578
579
# File 'lib/google/apis/datalineage_v1/classes.rb', line 577

def link
  @link
end

#start_timeString

The start of the first event establishing this link-process tuple. Corresponds to the JSON property startTime

Returns:

  • (String)


582
583
584
# File 'lib/google/apis/datalineage_v1/classes.rb', line 582

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



589
590
591
592
593
# File 'lib/google/apis/datalineage_v1/classes.rb', line 589

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @link = args[:link] if args.key?(:link)
  @start_time = args[:start_time] if args.key?(:start_time)
end