Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinkInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Link details.
Instance Attribute Summary collapse
-
#end_time ⇒ String
The end of the last event establishing this link-process tuple.
-
#link ⇒ String
The name of the link in the format of
projects/project/locations/location/ links/link``. -
#start_time ⇒ String
The start of the first event establishing this link-process tuple.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1ProcessLinkInfo
constructor
A new instance of GoogleCloudDatacatalogLineageV1ProcessLinkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1ProcessLinkInfo
Returns a new instance of GoogleCloudDatacatalogLineageV1ProcessLinkInfo.
584 585 586 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
The end of the last event establishing this link-process tuple.
Corresponds to the JSON property endTime
571 572 573 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 571 def end_time @end_time end |
#link ⇒ String
The name of the link in the format of projects/project/locations/location/
links/link`.
Corresponds to the JSON propertylink`
577 578 579 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 577 def link @link end |
#start_time ⇒ String
The start of the first event establishing this link-process tuple.
Corresponds to the JSON property startTime
582 583 584 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 582 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
589 590 591 592 593 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 589 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @link = args[:link] if args.key?(:link) @start_time = args[:start_time] if args.key?(:start_time) end |