Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinks
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinks
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Links associated with a specific process.
Instance Attribute Summary collapse
-
#links ⇒ Array<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinkInfo>
An array containing link details objects of the links provided in the original request.
-
#process ⇒ String
The process name in the format of
projects/project/locations/location/ processes/process``.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1ProcessLinks
constructor
A new instance of GoogleCloudDatacatalogLineageV1ProcessLinks.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1ProcessLinks
Returns a new instance of GoogleCloudDatacatalogLineageV1ProcessLinks.
614 615 616 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#links ⇒ Array<Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1ProcessLinkInfo>
An array containing link details objects of the links provided in the original
request. A single process can result in creating multiple links. If any of the
links you provide in the request are created by the same process, they all are
included in this array.
Corresponds to the JSON property links
606 607 608 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 606 def links @links end |
#process ⇒ String
The process name in the format of projects/project/locations/location/
processes/process`.
Corresponds to the JSON propertyprocess`
612 613 614 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 612 def process @process end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
619 620 621 622 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 619 def update!(**args) @links = args[:links] if args.key?(:links) @process = args[:process] if args.key?(:process) end |