Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Limits for the search results.
Instance Attribute Summary collapse
-
#max_depth ⇒ Fixnum
Optional.
-
#max_process_per_link ⇒ Fixnum
Optional.
-
#max_results ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits
constructor
A new instance of GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits
Returns a new instance of GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits.
1007 1008 1009 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_depth ⇒ Fixnum
Optional. The maximum depth of the search. The default value is 5 and maximum
value is 100.
Corresponds to the JSON property maxDepth
989 990 991 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 989 def max_depth @max_depth end |
#max_process_per_link ⇒ Fixnum
Optional. The maximum number of processes to return per link. The default
value is 0 and the maximum value is 100. If this value is non-zero, the
response will contain process names for the links. To retrieve full process
details in the response, include links.processes.process in the FieldMask.
Corresponds to the JSON property maxProcessPerLink
999 1000 1001 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 999 def max_process_per_link @max_process_per_link end |
#max_results ⇒ Fixnum
Optional. The maximum number of links to return in the response. The default
value is 1_000 and the maximum value is 10_000.
Corresponds to the JSON property maxResults
1005 1006 1007 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1005 def max_results @max_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1012 1013 1014 1015 1016 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1012 def update!(**args) @max_depth = args[:max_depth] if args.key?(:max_depth) @max_process_per_link = args[:max_process_per_link] if args.key?(:max_process_per_link) @max_results = args[:max_results] if args.key?(:max_results) end |