Class: Google::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1SearchLinksRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb

Overview

Request message for SearchLinks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDatacatalogLineageV1SearchLinksRequest

Returns a new instance of GoogleCloudDatacatalogLineageV1SearchLinksRequest.



1088
1089
1090
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#page_sizeFixnum

Optional. The maximum number of links to return in a single page of the response. A page may contain fewer links than this value. If unspecified, at most 10 links are returned. Maximum value is 100; values greater than 100 are reduced to 100. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


1058
1059
1060
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1058

def page_size
  @page_size
end

#page_tokenString

Optional. The page token received from a previous SearchLinksRequest call. Use it to get the next page. When requesting subsequent pages of a response, remember that all parameters must match the values you provided in the original request. Corresponds to the JSON property pageToken

Returns:

  • (String)


1066
1067
1068
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1066

def page_token
  @page_token
end

#sourceGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property source



1071
1072
1073
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1071

def source
  @source
end

#sourcesGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1MultipleEntityReference

Multiple entity reference for SearchLinksRequest. Corresponds to the JSON property sources



1076
1077
1078
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1076

def sources
  @sources
end

#targetGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1EntityReference

The soft reference to everything you can attach a lineage event to. Corresponds to the JSON property target



1081
1082
1083
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1081

def target
  @target
end

#targetsGoogle::Apis::DatalineageV1::GoogleCloudDatacatalogLineageV1MultipleEntityReference

Multiple entity reference for SearchLinksRequest. Corresponds to the JSON property targets



1086
1087
1088
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1086

def targets
  @targets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1093
1094
1095
1096
1097
1098
1099
1100
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1093

def update!(**args)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @source = args[:source] if args.key?(:source)
  @sources = args[:sources] if args.key?(:sources)
  @target = args[:target] if args.key?(:target)
  @targets = args[:targets] if args.key?(:targets)
end