Class: Google::Apis::DatalineageV1::GoogleTypeInterval
- Inherits:
-
Object
- Object
- Google::Apis::DatalineageV1::GoogleTypeInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datalineage_v1/classes.rb,
lib/google/apis/datalineage_v1/representations.rb,
lib/google/apis/datalineage_v1/representations.rb
Overview
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeInterval
constructor
A new instance of GoogleTypeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeInterval
Returns a new instance of GoogleTypeInterval.
1313 1314 1315 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. Exclusive end of the interval. If specified, a Timestamp matching
this interval will have to be before the end.
Corresponds to the JSON property endTime
1305 1306 1307 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1305 def end_time @end_time end |
#start_time ⇒ String
Optional. Inclusive start of the interval. If specified, a Timestamp matching
this interval will have to be the same or after the start.
Corresponds to the JSON property startTime
1311 1312 1313 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1311 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1318 1319 1320 1321 |
# File 'lib/google/apis/datalineage_v1/classes.rb', line 1318 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |